@@ -2,7 +2,7 @@
 #
 #  File: afl-cov
 #
-#  Version: 0.6.1
+#  Version: 0.6.2
 #
 #  Purpose: Perform lcov coverage diff's against each AFL queue file to see
 #           new functions and line coverage evolve from an AFL fuzzing cycle.
@@ -44,7 +44,7 @@ try:
 except ImportError:
     import subprocess
 
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 
 NO_OUTPUT   = 0
 WANT_OUTPUT = 1
@@ -311,7 +311,11 @@ def coverage_diff(cycle_num, fuzz_dir, cov_paths, afl_file, cov, cargs):
         delta_file = 'id:[%d-%d]...' % \
                 (cov_paths['id_min'], cov_paths['id_max'])
 
-    new_cov = extract_coverage(cov_paths['lcov_info_final'], cargs)
+    new_cov = extract_coverage(cov_paths['lcov_info_final'],
+            cov_paths['log_file'], cargs)
+
+    if not new_cov:
+        return
 
     ### We aren't interested in the number of times AFL has executed
     ### a line or function (since we can't really get this anyway because
@@ -452,11 +456,16 @@ def cov_init(cfile, cov):
             cov[k][cfile]['line'] = {}
     return
 
-def extract_coverage(lcov_file, cargs):
+def extract_coverage(lcov_file, log_file, cargs):
 
     search_rv = False
     tmp_cov = {}
 
+    if not os.path.exists(lcov_file):
+        logr("[-] Coverage file '%s' does not exist, skipping." % lcov_file,
+                log_file, cargs)
+        return tmp_cov
+
     ### populate old lcov output for functions/lines that were called
     ### zero times
     with open(lcov_file, 'r') as f:
@@ -708,10 +717,12 @@ def run_cmd(cmd, log_file, cargs, collect):
                 out.append(line.rstrip('\n'))
         os.unlink(fh.name)
 
-    if (es != 0) and (collect == LOG_ERRORS):
+    if (es != 0) and (collect == LOG_ERRORS or collect == WANT_OUTPUT):
         if log_file:
             logr("    Non-zero exit status '%d' for CMD: %s" % (es, cmd),
                     log_file, cargs)
+            for line in out:
+                logr(line, log_file, cargs)
         else:
             print "    Non-zero exit status '%d' for CMD: %s" % (es, cmd)
 
@@ -821,7 +832,13 @@ def is_bin_gcov_enabled(binary, cargs):
             False, cargs, WANT_OUTPUT)[1]:
         if ' __gcov' in line:
             if cargs.validate_args or cargs.gcov_check or cargs.gcov_check_bin:
-                print "[+] Binary '%s' is compiled with code coverage support." % binary
+                print "[+] Binary '%s' is compiled with code coverage support via gcc." % binary
+            rv = True
+            break
+
+        if '__llvm_gcov' in line:
+            if cargs.validate_args or cargs.gcov_check or cargs.gcov_check_bin:
+                print "[+] Binary '%s' is compiled with code coverage support via llvm." % binary
             rv = True
             break
 
@@ -887,7 +904,7 @@ def is_gcov_enabled(cargs):
         found_code_cov_binary = False
 
         for part in cargs.coverage_cmd.split(' '):
-            if part[0] == ' ' or part[0] == '-':
+            if not part or part[0] == ' ' or part[0] == '-':
                 continue
             if (which(part)):
                 found_exec = True
